@@ -1,5 +1,3 @@
-from troposphere.sqs import Queue
-
 from serverless.aws.functions.generic import Function
 from serverless.service.types import YamlOrderedDict
 
@@ -43,9 +41,13 @@ class EventBridgeFunction(Function):
         handler=None,
         timeout=None,
         layers=None,
+        use_dlq=True,
+        use_async_dlq=True,
         **kwargs,
     ):
-        super().__init__(service, name, description, handler, timeout, layers, **kwargs)
+        super().__init__(
+            service, name, description, handler, timeout, layers, use_dlq=use_dlq, use_async_dlq=use_async_dlq, **kwargs
+        )
         self.trigger(EventBridgeEvent(eventBus, pattern, deadLetterQueueArn, retryPolicy))
         self.use_async_dlq()
         self.use_dlq()
